local FONT_FACE = STANDARD_TEXT_FONT --"Fonts\FRIZQT__.TTF"
local FONT_SIZE = 10


BetterPowerBarAltDB = BetterPowerBarAltDB or {}


PlayerPowerBarAlt:SetSize(64, 64)
PlayerPowerBarAlt:SetMovable(true)
PlayerPowerBarAlt:SetUserPlaced(true)


local overlay = CreateFrame("Frame", nil, PlayerPowerBarAlt)
overlay:SetAllPoints()

local text = overlay:CreateFontString(nil, "OVERLAY")
text:SetAllPoints(overlay)
text:SetFont(FONT_FACE, FONT_SIZE)
text:SetJustifyH("CENTER")
text:SetJustifyV("MIDDLE")
text:SetTextColor(1, 1, 1, 1)
text:SetShadowOffset(0.8, -0.8)
text:SetShadowColor(0, 0, 0, 1)
overlay.text = text

local texture = overlay:CreateTexture()
texture:SetAllPoints()
texture:SetTexture(1, 1, 1, 0.1)
texture:Hide()
overlay.texture = texture

overlay:EnableMouse(true)
overlay.isLocked = true
overlay:SetScript("OnMouseDown", function(self, button)
	if button == "LeftButton" and not self.isLocked then
		PlayerPowerBarAlt:StartMoving()
		self.isMoving = true
	end
end)
overlay:SetScript("OnMouseUp", function(self, button)
	if button == "RightButton" then
		self.isLocked = not self.isLocked
		if self.isLocked then
			self.texture:Hide()
		else
			self.texture:Show()
		end
	elseif self.isMoving then
		PlayerPowerBarAlt:StopMovingOrSizing()
		self.isMoving = nil
		local point, _, _, x, y = PlayerPowerBarAlt:GetPoint(1)
	elseif IsShiftKeyDown() then
		BetterPowerBarAltDB.hideText = not BetterPowerBarAltDB.hideText
		self:UpdateText()
	end
end)

overlay:SetScript("OnEnter", function(self)
	GameTooltip_SetDefaultAnchor(GameTooltip, self)
	GameTooltip:SetText(self:GetParent().powerName, 1, 1, 1)
	GameTooltip:AddLine(self:GetParent().powerTooltip, nil, nil, nil, 1)
	GameTooltip:Show()
	
	if BetterPowerBarAltDB.hideText then
		self.text:Show()
	end
end)
overlay:SetScript("OnLeave", function(self)
	GameTooltip:Hide()
	
	if BetterPowerBarAltDB.hideText then
		self.text:Hide()
	end
end)

overlay:SetScript("OnShow", function(self)
	self:SetAllPoints()
	self:RegisterEvent("UNIT_POWER")
	self:RegisterEvent("UNIT_MAXPOWER")
	self:UpdateText()
end)
overlay:SetScript("OnHide", function(self)
	self:UnregisterEvent("UNIT_POWER")
	self:UnregisterEvent("UNIT_MAXPOWER")
end)

overlay:SetScript("OnEvent", function(self, event, unit, powerType)
	if unit == "player" and powerType == "ALTERNATE" then
		self:UpdateText()
	end
end)

function overlay:UpdateText()
	local power, maxPower = UnitPower("player", ALTERNATE_POWER_INDEX), UnitPowerMax("player", ALTERNATE_POWER_INDEX)
	
	self.displayedValue = maxPower > 0 and power > 0 and string.format("%d%%", power / maxPower * 100) or "0%"
	self.text:SetText(self.displayedValue)
	
	if power <= 0 then
		self.text:Hide()
	elseif not BetterPowerBarAltDB.hideText then
		self.text:Show()
	end
end
